@@ -27,6 +27,10 @@
  *      Peter Vrabec <pvrabec@redhat.com>
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <stdio.h>
 #include <string.h>
 #include <sys/types.h>
@@ -455,3 +459,4 @@ static void rglobfree(rglob_t * result)
 	result->pathc = 0;
 }
 
+/// @}
