@@ -46,6 +46,7 @@
 #include <pthread.h>
 #include <errno.h>
 #include <crapi/crapi.h>
+#include <probe/probe.h>
 #include <probe/option.h>
 
 #include "common/debug_priv.h"
@@ -212,10 +213,10 @@ void *probe_init (void)
 	case 0:
 		return ((void *)&__filehash58_probe_mutex);
 	default:
-		dI("Can't initialize mutex: errno=%u, %s.\n", errno, strerror (errno));
+		dI("Can't initialize mutex: errno=%u, %s.", errno, strerror (errno));
 	}
 
-	probe_setoption(PROBEOPT_OFFLINE_MODE_SUPPORTED, true);
+	probe_setoption(PROBEOPT_OFFLINE_MODE_SUPPORTED, PROBE_OFFLINE_CHROOT);
 
 	return (NULL);
 }
@@ -274,7 +275,7 @@ int probe_main(probe_ctx *ctx, void *mutex)
 	case 0:
 		break;
 	default:
-		dI("Can't lock mutex(%p): %u, %s.\n", &__filehash58_probe_mutex, errno, strerror (errno));
+		dI("Can't lock mutex(%p): %u, %s.", &__filehash58_probe_mutex, errno, strerror (errno));
 
 		err = PROBE_EFATAL;
 		goto cleanup;
@@ -310,7 +311,7 @@ cleanup:
 	case 0:
 		break;
 	default:
-		dI("Can't unlock mutex(%p): %u, %s.\n", &__filehash58_probe_mutex, errno, strerror (errno));
+		dI("Can't unlock mutex(%p): %u, %s.", &__filehash58_probe_mutex, errno, strerror (errno));
 
 		err = PROBE_EFATAL;
 	}
