@@ -56,10 +56,18 @@ struct oval_results_model {
 	struct oval_directives_model *directives_model;
 	struct oval_definition_model *definition_model;
 	struct oval_collection *systems;
+	struct oval_probe_session *probe_session;
 };
 
 struct oval_results_model *oval_results_model_new(struct oval_definition_model *definition_model,
 						  struct oval_syschar_model **syschar_models)
+{
+	return oval_results_model_new_with_probe_session(definition_model, syschar_models, NULL);
+}
+
+struct oval_results_model *oval_results_model_new_with_probe_session(struct oval_definition_model *definition_model,
+						  struct oval_syschar_model **syschar_models,
+						  struct oval_probe_session *probe_session)
 {
 	struct oval_results_model *model = (struct oval_results_model *) oscap_alloc(sizeof(struct oval_results_model));
 	if (model == NULL)
@@ -78,6 +86,7 @@ struct oval_results_model *oval_results_model_new(struct oval_definition_model *
 		}
 	}
 	model->directives_model = oval_directives_model_new();
+	model->probe_session = probe_session;
 	return model;
 }
 
@@ -139,6 +148,12 @@ struct oval_result_system_iterator *oval_results_model_get_systems(struct oval_r
 	    oval_collection_iterator(model->systems);
 }
 
+struct oval_probe_session *oval_results_model_get_probe_session(struct oval_results_model *model)
+{
+	__attribute__nonnull__(model);
+	return model->probe_session;
+}
+
 void oval_results_model_add_system(struct oval_results_model *model, struct oval_result_system *sys)
 {
 	__attribute__nonnull__(model);
