@@ -717,6 +717,16 @@ struct cpe_check_cb_usr
 	struct cpe_lang_model* lang_model;
 };
 
+/**
+ * Return true if path starts with '.' or './'
+ */
+static bool is_path_relative_subdir(const char* path) {
+	if ( path[0] == '.' ) {
+		if ( path[1] == '/' || path[1] == '\0' ) return true;
+	}
+	return false;
+}
+
 static char *_cpe_get_oval_href(struct cpe_dict_model *dict, struct cpe_lang_model *lang_model, const char *oval_relative_href)
 {
 	char *oval_href = NULL;
@@ -737,7 +747,7 @@ static char *_cpe_get_oval_href(struct cpe_dict_model *dict, struct cpe_lang_mod
 		// we need to strdup because dirname potentially alters the string
 		origin_file = oscap_strdup(origin_file_c ? origin_file_c : "");
 		const char* prefix_dirname = dirname(origin_file);
-		if (oscap_streq(prefix_dirname, ".")) {
+		if (is_path_relative_subdir(prefix_dirname)) {
 			// The path is relative. Do not overide it.
 			// Chances are that ds_sds_session expects the very same href
 			oval_href = oscap_strdup(oval_relative_href);
@@ -1832,60 +1842,21 @@ struct xccdf_select_iterator * xccdf_policy_get_selected_rules(struct xccdf_poli
                                                                        policy);
 }
 
-OSCAP_DEPRECATED(
 bool xccdf_policy_set_selected(struct xccdf_policy * policy, char * idref) {
 	return false;
 }
-)
 
 /**
  * Get Policy from Policy model by it's id.
  */
 struct xccdf_policy * xccdf_policy_model_get_policy_by_id(struct xccdf_policy_model * policy_model, const char * id)
 {
-    struct xccdf_policy_iterator * policy_it;
-    struct xccdf_policy          * policy;
-
-    policy_it = xccdf_policy_model_get_policies(policy_model);
-    while (xccdf_policy_iterator_has_more(policy_it)) {
-        policy = xccdf_policy_iterator_next(policy_it);
-        if (oscap_streq(xccdf_policy_get_id(policy), id)) {
-            xccdf_policy_iterator_free(policy_it);
-            return policy;
-        }
-    }
-    xccdf_policy_iterator_free(policy_it);
-
-	struct xccdf_profile *profile = NULL;
-	struct xccdf_tailoring *tailoring = xccdf_policy_model_get_tailoring(policy_model);
-
-	// Tailoring profiles take precedence over Benchmark profiles.
-	if (tailoring) {
-		profile = xccdf_tailoring_get_profile_by_id(tailoring, id);
+	struct xccdf_policy *policy = xccdf_policy_model_get_existing_policy_by_id(policy_model, id);
+	if (policy != NULL) {
+		return policy;
 	}
 
-	if (!profile) {
-		if (id == NULL) {
-			profile = xccdf_profile_new();
-			xccdf_profile_set_id(profile, NULL);
-			struct oscap_text * title = oscap_text_new();
-			oscap_text_set_text(title, "No profile (default benchmark)");
-			oscap_text_set_lang(title, "en");
-			xccdf_profile_add_title(profile, title);
-		}
-		else {
-			struct xccdf_benchmark *benchmark = xccdf_policy_model_get_benchmark(policy_model);
-			if (benchmark == NULL) {
-				assert(benchmark != NULL);
-				return NULL;
-			}
-			profile = xccdf_benchmark_get_profile_by_id(benchmark, id);
-			if (profile == NULL)
-				return NULL;
-		}
-	}
-
-	policy = xccdf_policy_new(policy_model, profile);
+	policy = xccdf_policy_model_create_policy_by_id(policy_model, id);
 	if (policy != NULL)
 		oscap_list_add(policy_model->policies, policy);
 	return policy;
