@@ -331,7 +331,12 @@ static inline int _xccdf_fix_execute(struct xccdf_rule_result *rr, struct xccdf_
 				NULL
 			};
 
-			execve(interpret, argvp, NULL);
+			char *const envp[2] = {
+				"PATH=/bin:/sbin:/usr/bin:/usr/sbin",
+				NULL
+			};
+
+			execve(interpret, argvp, envp);
 			/* Wow, execve returned. In this special case, we failed to execute the fix
 			 * and we return 0 from function. At least the following error message will
 			 * indicate the problem in xccdf:message. */
